@@ -1,8 +1,8 @@
 /*
 // pgAgent - PostgreSQL Tools
-// $Id: pgagent.sql 8019 2009-09-01 11:59:21Z dpage $
-// Copyright (C) 2002 - 2009 The pgAdmin Development Team
-// This software is released under the BSD Licence
+// 
+// Copyright (C) 2002 - 2012 The pgAdmin Development Team
+// This software is released under the PostgreSQL Licence
 //
 // pgagent.sql - pgAgent tables and functions
 //
@@ -144,7 +144,7 @@ COMMENT ON TABLE pgagent.pga_jobsteplog IS 'Job step run logs.';
 COMMENT ON COLUMN pgagent.pga_jobsteplog.jslstatus IS 'Status of job step: r=running, s=successfully finished,  f=failed stopping job, i=ignored failure, d=aborted';
 COMMENT ON COLUMN pgagent.pga_jobsteplog.jslresult IS 'Return code of job step';
 
-CREATE FUNCTION pgagent.pgagent_schema_version() RETURNS int2 AS '
+CREATE OR REPLACE FUNCTION pgagent.pgagent_schema_version() RETURNS int2 AS '
 BEGIN
     -- RETURNS PGAGENT MAJOR VERSION
     -- WE WILL CHANGE THE MAJOR VERSION, ONLY IF THERE IS A SCHEMA CHANGE
@@ -559,7 +559,7 @@ BEGIN
     RETURN $1 % 400 = 0;
 END;
 ' LANGUAGE 'plpgsql' IMMUTABLE;
-COMMENT ON FUNCTION pgagent.pga_is_leap_year(int2) IS 'Returns TRUE is $1 is a leap year';
+COMMENT ON FUNCTION pgagent.pga_is_leap_year(int2) IS 'Returns TRUE if $1 is a leap year';
 
 
 CREATE OR REPLACE FUNCTION pgagent.pga_job_trigger()
